Struct avalanche_proto::http::ConnectionState
source · [−]pub struct ConnectionState {
pub version: u32,
pub handshake_complete: bool,
pub did_resume: bool,
pub cipher_suite: u32,
pub negotiated_protocol: String,
pub server_name: String,
pub peer_certificates: Option<Certificates>,
pub verified_chains: Vec<Certificates>,
pub signed_certificate_timestamps: Vec<Bytes>,
pub ocsp_response: Bytes,
}Expand description
ConnectionState is tls.ConnectionState see: https://pkg.go.dev/crypto/tls#ConnectionState
Fields
version: u32version is the TLS version used by the connection (e.g. VersionTLS12)
handshake_complete: boolhandshake_complete is true if the handshake has concluded
did_resume: booldid_resume is true if this connection was successfully resumed from a previous session with a session ticket or similar mechanism
cipher_suite: u32cipher_suite is the cipher suite negotiated for the connection
negotiated_protocol: Stringnegotiated_protocol is the application protocol negotiated with ALPN
server_name: Stringserver_name is the value of the Server Name Indication extension sent by the client
peer_certificates: Option<Certificates>peer_certificates are the parsed certificates sent by the peer, in the order in which they were sent
verified_chains: Vec<Certificates>verified_chains is a list of one or more chains where the first element is PeerCertificates[0] and the last element is from Config.RootCAs (on the client side) or Config.ClientCAs (on the server side).
signed_certificate_timestamps: Vec<Bytes>signed_certificate_timestamps is a list of SCTs provided by the peer through the TLS handshake for the leaf certificate, if any
ocsp_response: Bytesocsp_response is a stapled Online Certificate Status Protocol (OCSP) response provided by the peer for the leaf certificate, if any.