Struct avalanche_proto::http::HandleSimpleHttpRequest
source · [−]pub struct HandleSimpleHttpRequest {
pub method: String,
pub url: String,
pub headers: Vec<Element>,
pub body: Bytes,
}Fields
method: Stringmethod specifies the HTTP method (GET, POST, PUT, etc.)
url: Stringurl specifies either the URI being requested
headers: Vec<Element>headers contains the request header fields either received by the server or to be sent by the client
body: Bytesbody is the request payload in bytes